==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""

, "Backend"
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: ""

, "Hostname"
: ""

, "Username"
: ""

, "Password"
: ""

, "Port"
: ""

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: ""

, "SSL"
: ""

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "No"
: ""

, "Yes"
: ""

, "Append domain to login name"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: ""

, "Setup Checks"
: "檢查設定"

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "Setup"
: ""

, "Name"
: "姓名"

, "Enabled"
: "啟用"

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: "狀態"

, "Depends on"
: ""

, "Install application"
: "安裝應用程式"

, "Uninstall application"
: "移除應用程式"

, "Update application"
: "更新應用程式"

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "檢查"

, "Result"
: ""

, "Error"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Application, Applications"
: [
  "應用程式"

]
, "File"
: ""

, "Setup Authentication"
: ""

, "Database"
: ""

, "User"
: ""

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: ""

, "Priority"
: ""

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "應用程式"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-zh_TW-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (Taiwan) (http://www.transifex.com/tine20/tine20/language/zh_TW/)\nLanguage: zh_TW\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: ""

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "檢查"

, "Result"
: ""

, "Message"
: ""

, "Run setup tests"
: ""

, "Ignore setup tests"
: ""

, "Install application"
: "安裝應用程式"

, "Name"
: "姓名"

, "Enabled"
: "啟用"

, "Order"
: ""

, "Installed Version"
: ""

, "Available Version"
: ""

, "Status"
: "狀態"

, "Depends on"
: ""

, "Uninstall application"
: "移除應用程式"

, "Update applications"
: ""

, "Go to {0} login"
: ""

, "uninstall"
: ""

, "Do you really want to uninstall the application(s)?"
: ""

, "This may take a while"
: ""

, "Dependency Violation"
: ""

, "CLI Required"
: ""

, "Delete all existing users and groups"
: ""

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: ""

, "Backend"
: ""

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: ""

, "Initial admin Password"
: ""

, "Password confirmation"
: ""

, "Authentication provider"
: ""

, "Try to split username"
: ""

, "Yes"
: ""

, "No"
: ""

, "Account canonical form"
: ""

, "Account domain name"
: ""

, "Account domain short name"
: ""

, "Host"
: ""

, "Login name"
: ""

, "Password"
: ""

, "Bind requires DN"
: ""

, "Start TLS"
: ""

, "SSL"
: ""

, "Port"
: ""

, "Base DN"
: ""

, "Search filter"
: ""

, "Hostname"
: ""

, "Secure Connection"
: ""

, "None"
: ""

, "TLS"
: ""

, "Append domain to login name"
: ""

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: ""

, "Default user group name"
: ""

, "Default admin group name"
: ""

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: ""

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: ""

, "Redirect Url (redirect to login screen if empty)"
: ""

, "Redirect Always (if No, only redirect after logout)"
: ""

, "Redirect to referring site, if exists"
: ""

, "Password encoding"
: ""

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: ""

, "User Filter"
: ""

, "User Search Scope"
: ""

, "Groups DN"
: ""

, "Group Filter"
: ""

, "Group Search Scope"
: ""

, "Use Rfc 2307 bis"
: ""

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: ""

, "Max User Id"
: ""

, "Min Group Id"
: ""

, "Max Group Id"
: ""

, "Group UUID Attribute name"
: ""

, "User UUID Attribute name"
: ""

, "Readonly access"
: ""

, "Save config and install"
: ""

, "Save config"
: ""

, "Passwords don't match"
: ""

, "Should not be empty"
: ""

, "File"
: ""

, "Setup Authentication"
: ""

, "Username"
: ""

, "Database"
: ""

, "User"
: ""

, "Prefix"
: ""

, "Logging"
: ""

, "Filename"
: ""

, "Priority"
: ""

, "Caching"
: ""

, "Lifetime (seconds)"
: ""

, "Path"
: ""

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: ""

, "Temporary Files Path"
: ""

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: ""

, "Map panel"
: ""

, "disabled"
: ""

, "enabled"
: ""

, "Config file is not writable"
: ""

, "Download config file"
: ""

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: ""

, "Standard SMTP"
: ""

, "Imap"
: ""

, "Verify peer Certificate"
: ""

, "Use system account"
: ""

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: ""

, "Authentication"
: ""

, "Login"
: ""

, "Plain"
: ""

, "Primary Domain"
: ""

, "Secondary Domains (comma separated)"
: ""

, "Notifications service address"
: ""

, "Notification Username"
: ""

, "Notification Password"
: ""

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: ""

, "MySql Database"
: ""

, "MySql User"
: ""

, "MySql Password"
: ""

, "MySql Port"
: ""

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Setup"
: ""

, "Application, Applications"
: [
  "應用程式"

]
, "Terms and Conditions"
: ""

, "Setup Checks"
: "檢查設定"

, "Config Manager"
: ""

, "Authentication/Accounts"
: ""

, "Email"
: ""

, "Application Manager"
: ""

, "I have read the license agreement and accept it"
: ""

, "License Agreement"
: ""

, "I have read the privacy agreement and accept it"
: ""

, "Privacy Agreement"
: ""

, "Accept Terms and Conditions"
: ""


, "Application"
: "應用程式"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
